@@ -1,13 +1,15 @@
 import copy
 import datetime
-from typing import Tuple, Literal
+from typing import Tuple, Literal, Dict, Union
 from dataclasses import dataclass
+from functools import cached_property
 
 import numpy as np  # type: ignore
 from astropy.wcs import WCS  # type: ignore
 from dkist_fits_specifications import spec122
+from dkist_fits_specifications.spec214 import level0 as spec214_level0
 
-from dkist_data_simulator.dataset import Dataset, key_function
+from dkist_data_simulator.dataset import Dataset, key_function, Copy
 from dkist_data_simulator.schemas import Schema, TimeKey
 
 __all__ = ['Spec122Dataset', 'Spec122Schema']
@@ -16,20 +18,18 @@ __all__ = ['Spec122Dataset', 'Spec122Schema']
 KNOWN_INSTRUMENT_TABLES = {
     'vbi': 'VBI',
     'visp': 'VISP',
-    'dlnirsp': 'DL_NIRSP',
+    'dlnirsp': 'DL-NIRSP',
     'cryonirsp': 'CRYO-NIRSP',
     'vtf': 'VTF',
 }
 
 
 @dataclass(init=False)
-class Spec122Schema(Schema):
+class Level0Schema(Schema):
     """
-    A representation of the 122 schema.
+    A representation of a Level 0 schema.
     """
-
     def __init__(self, instrument=None):
-        sections = spec122.load_spec122()
         if instrument:
             if instrument not in KNOWN_INSTRUMENT_TABLES.keys():
                 raise ValueError(
@@ -39,9 +39,22 @@ class Spec122Schema(Schema):
             for table in KNOWN_INSTRUMENT_TABLES.keys():
                 if table == instrument:
                     continue
-                sections.pop(table)
+                self.sections.pop(table)
 
-        super().__init__(self.sections_from_dicts(sections.values()))
+        super().__init__(self.sections_from_dicts(self.sections.values()))
+
+
+class Spec122Schema(Level0Schema):
+    @cached_property
+    def sections(self) -> Dict:
+        print()
+        return spec122.load_spec122()
+
+
+class Level0Spec214Schema(Level0Schema):
+    @cached_property
+    def sections(self) -> Dict:
+        return spec214_level0.load_level0_spec214()
 
 
 class Spec122Dataset(Dataset):
@@ -66,7 +79,11 @@ class Spec122Dataset(Dataset):
     instrument
         The name of the instrument, must match one of the instrument tables. If
         `None` all instrument tables will be used.
-
+    file_schema
+        The schema to use to generate files. This can be used to generate files
+        against the Spec 122 schema, as they will be transmitted from the
+        summit, or the spec214 level 0 schema which is how data will be stored
+        at the data center.
     """
 
     def __init__(self,
@@ -74,13 +91,19 @@ class Spec122Dataset(Dataset):
                  array_shape: Tuple[int, ...],
                  time_delta: float,
                  start_time: datetime.datetime = None,
-                 instrument: Literal[tuple(KNOWN_INSTRUMENT_TABLES.keys())] = None):
+                 instrument: Literal[tuple(KNOWN_INSTRUMENT_TABLES.keys())] = None,
+                 file_schema: Union[Schema, Literal["spec122", "level0_spec214"]] = "spec122"):
 
         self.time_delta = time_delta
         self.start_time = start_time or datetime.datetime.fromisoformat(
             TimeKey("", False, False).generate_value())
 
-        super().__init__(file_schema=Spec122Schema(instrument),
+        if file_schema == "spec122":
+            file_schema = Spec122Schema(instrument)
+        if file_schema == "level0_spec214":
+            file_schema = Level0Spec214Schema(instrument)
+
+        super().__init__(file_schema=file_schema,
                          dataset_shape=dataset_shape,
                          array_shape=array_shape)
 
@@ -91,8 +114,8 @@ class Spec122Dataset(Dataset):
         self.add_constant_key("NAXIS1", self.array_shape[2])
         self.add_constant_key("NAXIS2", self.array_shape[1])
         self.add_constant_key("NAXIS3", self.array_shape[0])
-        self.add_constant_key("DATE-BGN", self.start_time.isoformat('T'))
-        self.add_constant_key("DATE-END", end_time.isoformat('T'))
+        self.add_constant_key("DKIST011", self.start_time.isoformat('T'))
+        self.add_constant_key("DKIST012", end_time.isoformat('T'))
         self.add_constant_key("ORIGIN", "National Solar Observatory")
         self.add_constant_key("TELESCOP", "Daniel K. Inouye Solar Telescope")
         self.add_constant_key("OBSERVAT", "Haleakala High Altitude Observatory Site")
@@ -102,6 +125,17 @@ class Spec122Dataset(Dataset):
         # WCS
         self.add_constant_key("CRDATEn")
 
+        # Level 0 spec 214 key copying
+        if isinstance(file_schema, Level0Spec214Schema):
+            level0_214_122_map = spec214_level0.spec214_122_key_map()
+
+            # Add a Copy action class to the header for each target key we
+            # want, but set the flag so the target key is only added if the
+            # source key is in the generated header.
+            self.add_generator_function(tuple(level0_214_122_map.keys()),
+                                        lambda self, key: Copy(level0_214_122_map[key],
+                                                               if_present=True))
+
     @property
     def data(self):
         return np.empty(self.array_shape)
