@@ -127,24 +127,17 @@ class Spec214Dataset(Dataset):
           self.add_constant_key("SWBIN1", 1)
           self.add_constant_key("SWBIN2", 1)
 
-        # ROI
-        for suf in ["OX", "OY", "SX", "SY"]:
-            for r in range(swnroi + 1, 4 + 1):
-                self.add_remove_key(f"SWROI{r}{suf}")
-            for r in range(hwnroi + 1, 2 + 1):
-                self.add_remove_key(f"HWROI{r}{suf}")
-
         self.add_constant_key("SWNROI", swnroi)
         self.add_constant_key("HWNROI", hwnroi)
 
         # Solarnet
         self.add_constant_key("BTYPE", "phot.count")
         self.add_constant_key("SOLARNET", 1.0)
-        self.add_constant_key("EXTNAME", 'observation')
+        self.add_constant_key("EXTNAME", 'OBSERVATION')
         self.add_constant_key("INFO_URL", "https://youtu.be/YddwkMJG1Jo")
 
         # WCS
-        self.add_constant_key("WCSNAME", "Helioprojective Cartesian")
+        self.add_constant_key("WCSNAME", "Helioprojective-cartesian")
         self.add_constant_key("CRDATEn")
         self.add_remove_key("LATPOLE")
 
@@ -501,7 +494,7 @@ class WCSAMixin:
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.add_constant_key("WCSNAMEA", "Equatorial")  # TODO: What will this be??
+        self.add_constant_key("WCSNAMEA", "Equatorial equinox J2000")
         self.add_remove_key("LATPOLEA")
         self.add_constant_key("CRDATEnA")
 
