@@ -28,6 +28,10 @@ class DatasetTest214(Spec214Dataset):
         w.wcs.pc = np.identity(self.array_ndim)
         return w
 
+    @property
+    def data(self):
+        return np.random.random(self.array_shape)
+
 
 @pytest.mark.parametrize("ds", (
     DatasetTest214(dataset_shape=(2, 2, 2, 40, 50),
@@ -84,7 +88,9 @@ class DatasetTest214(Spec214Dataset):
                          time_delta=10,
                          linewave=400 * u.nm
                          ),
-))
+), ids=["DatasetTest214", "SimpleVISPDataset-polarized", "SimpleVISPDataset", "SimpleVBIDataset",
+        "SimpleVTFDataset-polarized", "SimpleVTFDataset", "SimpleCRYODataset-polarized",
+        "SimpleCRYODataset", "SimpleDLNIRSPDataset-polarized", "SimpleDLNIRSPDataset"])
 def test_generate_214(ds):
     headers = ds.generate_headers()
 
